@@ -275,7 +275,7 @@ NEIGHBOURS = {
     'AT': ['CH', 'CZ', 'DE_LU', 'HU', 'IT_NORD', 'SI'],
     'CZ': ['AT', 'DE_AT_LU', 'DE_LU', 'PL', 'SK'],
     'GB': ['BE', 'FR', 'IE_SEM', 'NL'],
-    'NO_2': ['DK_1', 'NL', 'NO_5'],
+    'NO_2': ['DE_LU', 'DK_1', 'NL', 'NO_1', 'NO_5'],
     'HU': ['AT', 'HR', 'RO', 'RS', 'SK', 'UA'],
     'IT_NORD': ['CH', 'DE_AT_LU', 'FR', 'SI', 'AT', 'IT_CNOR'],
     'ES': ['FR', 'PT'],
@@ -287,7 +287,7 @@ NEIGHBOURS = {
     'RO': ['BG', 'HU', 'RS', 'UA'],
     'LT': ['BY', 'LV', 'PL', 'RU_KGD', 'SE_4'],
     'BG': ['GR', 'MK', 'RO', 'RS', 'TR'],
-    'SE_3': ['DK_1', 'FI', 'NO_1', 'SE_4'],
+    'SE_3': ['DK_1', 'FI', 'NO_1', 'SE_2', 'SE_4'],
     'LV': ['EE', 'LT', 'RU'],
     'IE_SEM': ['GB'],
     'BA': ['HR', 'ME', 'RS'],
@@ -296,16 +296,16 @@ NEIGHBOURS = {
     'NO_5': ['NO_1', 'NO_2', 'NO_3'],
     'SK': ['CZ', 'HU', 'PL', 'UA'],
     'EE': ['FI', 'LV', 'RU'],
-    'DK_2': ['DE_AT_LU', 'DE_LU', 'SE_4'],
+    'DK_2': ['DE_AT_LU', 'DE_LU', 'DK_1', 'SE_4'],
     'FI': ['EE', 'NO_4', 'RU', 'SE_1', 'SE_3'],
-    'NO_4': ['SE_2', 'FI', 'SE_1'],
+    'NO_4': ['SE_2', 'FI', 'NO_3', 'SE_1'],
     'SE_1': ['FI', 'NO_4', 'SE_2'],
-    'SE_2': ['NO_3', 'NO_4', 'SE_3'],
-    'DE_LU': ['AT', 'BE', 'CH', 'CZ', 'DK_1', 'DK_2', 'FR', 'NL', 'PL', 'SE_4'],
+    'SE_2': ['NO_3', 'NO_4', 'SE_1', 'SE_3'],
+    'DE_LU': ['AT', 'BE', 'CH', 'CZ', 'DK_1', 'DK_2', 'FR', 'NO_2', 'NL', 'PL', 'SE_4'],
     'MK': ['BG', 'GR', 'RS'],
     'PT': ['ES'],
     'GR': ['AL', 'BG', 'IT_BRNN', 'IT_GR', 'MK', 'TR'],
-    'NO_3': ['NO_4', 'NO_5', 'SE_2'],
+    'NO_3': ['NO_1', 'NO_4', 'NO_5', 'SE_2'],
     'IT': ['AT', 'FR', 'GR', 'MT', 'ME', 'SI', 'CH'],
     'IT_BRNN': ['GR', 'IT_SUD'],
     'IT_SUD': ['IT_BRNN', 'IT_CSUD', 'IT_FOGN', 'IT_ROSN', 'IT_CALA'],
